@@ -136,6 +136,7 @@ class TestUp(unittest.TestCase):
 			assert err is None
 			assert ret['key'] == key
 
+
 		test_put()
 		test_put_same_crc()
 		test_put_no_key()
@@ -171,11 +172,26 @@ class Test_get_file_crc32(unittest.TestCase):
 		file_path = '%s' % __file__
 
 		data = None
-		with open(file_path) as f:
+		with open(file_path, 'rb') as f:
 			data = f.read()
 		io._BLOCK_SIZE = 4
 		assert binascii.crc32(data) & 0xFFFFFFFF == io._get_file_crc32(file_path)
 
+	def test_get_un_utf8(self):
+		key = u"我很好".encode("utf-8")
+		#print "origin: %s" % key
+		data = urllib.urlopen('http://cheneya.qiniudn.com/hello_jpg')
+		ret, err = io.put(policy.token(), key, data)
+		assert err is None
+		print ret['key']
+		assert ret['key'] == key
+
+		#base_url = rs.make_base_url("cheneya.qiniudn.com", u"我很好".encode("utf-8"))
+		base_url = rs.make_base_url("cheneya.qiniudn.com", ret['key'])
+		data1 = urllib.urlopen(rs.GetPolicy().make_request(base_url))
+		print data1.read()
+		assert data1 == data
+
 
 if __name__ == "__main__":
 	unittest.main()
